@@ -4,6 +4,17 @@ import time
 import datetime
 from datetime import datetime
 
+def update_local_db_to_match_deluge(client):
+    check = client.call("core.get_torrents_status", {}, [])
+
+    for torr in torrent_db.get_all():
+        try:
+            encoded_id = torr.id.encode('utf-8')
+            this_item = check[encoded_id]
+            torrent_db.update_with_live_data(torr, this_item)
+        except KeyError as key:
+            print("Can't find info for " + str(torr.name))
+
 def check_progress(client):
     check = client.call("core.get_torrents_status", {}, [])
 
