@@ -142,6 +142,10 @@ def set_finished(change_id, finished):
     session.commit()
 
 
+def get_all():
+    session = scoped_session(sessionmaker(bind=engine))
+    return session.query(TorrentDownload).all()
+
 def get_all_active():
     session = scoped_session(sessionmaker(bind=engine))
     return session.query(TorrentDownload).filter_by(has_finished=0).all()
