@@ -179,7 +179,12 @@ def get_wantlist_for(user):
 
 def push_all_to_collection():
     for torr in torrent_db.get_all_complete():
-        mark_collected(torr.trakt_id, datetime.utcfromtimestamp(torr.time_added))
+        added_at = time.time()
+
+        if (torr.time_added != None):
+            added_at = torr.time_added
+
+        mark_collected(torr.trakt_id, datetime.utcfromtimestamp(added_at))
 
 
 def remove_all_from_wantlist():
